/**
 * @hidden
 * @packageDocumentation
 */
import { MathStructure } from "../model";
import { UndoRedoEditor } from "../../../standard-edition/editor/undo-redo-editor";
import { AnyNode } from "../../../standard-edition/model/model-base";
/**
 * Allows to modify semantic math tree based on heuristic rules.
 * The heuristic changes the visual formula representation but does not change its meaning.
 * For example, {@link VisibleMultiplyHeuristic} replaces implicit multiplication with explicit.
 * @category API
 */
export interface Heuristic {
    apply(tree: MathStructure, editor: UndoRedoEditor): boolean;
}
/**
 * Namespace contains {@link Heuristic} that allows to modify semantic math tree based on heuristic rules.
 */
export declare namespace Heuristics {
    /**
     * Returns the list of default {@link Heuristic} used by the editor.
     */
    function getDefault(): Heuristic[];
    /**
     * Returns the list of all available {@link Heuristic}.
     */
    function getAll(): Heuristic[];
    /**
     * Replaces implicit multiplication with explicit. For example, from xy to x*y.
     */
    class VisibleMultiplyHeuristic implements Heuristic {
        apply(tree: MathStructure, editor: UndoRedoEditor): boolean;
        isEndWithValue(node: AnyNode): boolean;
    }
}
