/**
 * @hidden
 * @packageDocumentation
 */
import { UndoRedoEditor } from "../editor/undo-redo-editor";
import { NavDirection, HorizontalNavDirection } from "../editor/editor";
import { UpDownHandler } from "../editor/up-down-handler";
import { RenderedTree } from "../editor/editor-support";
import * as Mousetrap from "mousetrap";
import { Point } from "../model/utils";
import { AdviceManager } from "../accessibility/advice-manager";
import { AdviceHtmlContainer, AdviceListPopup } from "../ui/advice-list-popup";
import { IAdvice } from "../accessibility/advices";
import { HorizontalDirection, VerticalDirection } from "../engine/utils";
export interface KeyboardShortcutPermissions {
    isLocked(): boolean;
    isReadOnly(): boolean;
    navigationAllowed(): boolean;
}
export interface KeyboardShortcutsCallbacks {
    onAdvicePopupShow(): void;
    onAdvicePopupHide(): void;
    onAdviceHover(adv: IAdvice): void;
    onEnter(): void;
}
export declare class KeyboardShortcuts {
    undoRedoEnabled: boolean;
    protected readonly mousetrap: Mousetrap.MousetrapInstance;
    protected readonly callbacks: KeyboardShortcutsCallbacks;
    protected readonly getRenderedTree: () => RenderedTree;
    readonly element: HTMLElement;
    readonly permissions: KeyboardShortcutPermissions;
    readonly hintListPopup: AdviceListPopup;
    readonly adviceManager: AdviceManager;
    protected storedAdvices: IAdvice[];
    readonly editor: UndoRedoEditor;
    private readonly eventRemover;
    private readonly upDown;
    constructor(element: HTMLElement, editor: UndoRedoEditor, upDown: UpDownHandler, getRenderedTree: () => RenderedTree, permissions: KeyboardShortcutPermissions, callbacks: KeyboardShortcutsCallbacks, adviceManager: AdviceManager);
    destroy(): void;
    lockUserInput(lock: boolean): void;
    private keyPress;
    handleKey(str: string): void;
    /**
    * @param {VerticalDirection} direction
    * @return {boolean} true if navigation happened (there was somewhere to go)
    */
    navigateVertically(direction: VerticalDirection): void;
    deleteOneAtCursor(direction: HorizontalDirection, force?: boolean): void;
    setupShortcuts(): void;
    showAdviceBox(advices: IAdvice[], showInLocked?: boolean): this;
    hideAdviceBox(): void;
    protected mapAdvices(startIndex: number): AdviceHtmlContainer[];
    applyAdvice(advice: IAdvice): void;
    paste(str: string): void;
    undo(): void;
    redo(): void;
    navigate(direction: HorizontalNavDirection): void;
    select(direction: NavDirection): void;
    moveSelectionHorizontalBoundary(left: boolean, direction: HorizontalDirection): void;
    moveSelectionVerticalBoundary(top: boolean, direction: VerticalDirection): void;
    selectAll(): void;
    protected filterAdvices(filterString: string): void;
    protected requestMoreAdvices(startIndex: number): void;
    protected calculatePosition(): Point;
}
