/**
 * @hidden
 * @packageDocumentation
 */
import { VisualGraph, VisualLevel, VisualSpace, VisualSymbol } from "../../structure/visual-levels";
import { HorizontalDirection, VerticalDirection } from "../utils";
import { Terminal } from "../../model/model-base";
import { TerminalSerializer } from "../../editor/terminal-serializer";
import { InnerSelection, SelectionHistory, SelectionVisitor } from "./utils";
export interface SerializedSpaceSelection {
    horizontalDirection: HorizontalDirection;
    verticalDirection: VerticalDirection;
    leftHorizontalIndex: number;
    leftVerticalIndex: number;
    rightHorizontalIndex: number;
    rightVerticalIndex: number;
    spaceHolderSymbol: string;
    spaceHolderLocation: string;
}
export declare class SpaceSelection implements InnerSelection {
    space: VisualSpace;
    horizontalDirection: HorizontalDirection | null;
    verticalDirection: VerticalDirection | null;
    leftHorizontalIndex: number;
    leftVerticalIndex: number;
    rightHorizontalIndex: number;
    rightVerticalIndex: number;
    selectionHistoryManager: SelectionHistory;
    constructor(space: VisualSpace, horizontalDirection: HorizontalDirection | null, verticalDirection: VerticalDirection | null, leftHorizontalIndex: number, leftVerticalIndex: number, rightHorizontalIndex: number, rightVerticalIndex: number, selectionHistoryManager: SelectionHistory);
    static createWithTwoLevels(selectionHistoryManager: SelectionHistory, space: VisualSpace, start: VisualLevel, stop: VisualLevel, initialHorizontalDirection: HorizontalDirection): SpaceSelection;
    static createWithLevel(selectionHistoryManager: SelectionHistory, space: VisualSpace, level: VisualLevel, direction: HorizontalDirection | VerticalDirection, rowHorizontalDirection: HorizontalDirection): InnerSelection;
    static createWithLevelTillCorner(selectionHistoryManager: SelectionHistory, space: VisualSpace, level: VisualLevel, horizontalDirection: HorizontalDirection, verticalDirection: VerticalDirection): InnerSelection;
    extendHorizontally(direction: HorizontalDirection): InnerSelection;
    getBoundary(horizontalDirection: HorizontalDirection, verticalDirection: VerticalDirection): VisualSymbol;
    get topIndex(): number;
    get bottomIndex(): number;
    get leftIndex(): number;
    get rightIndex(): number;
    get leftTopLevel(): VisualLevel;
    get leftBottomLevel(): VisualLevel;
    get rightTopLevel(): VisualLevel;
    get rightBottomLevel(): VisualLevel;
    get size(): number;
    get terminals(): Terminal[];
    shrinkHorizontally(direction: HorizontalDirection): InnerSelection;
    extendVertically(direction: VerticalDirection): InnerSelection;
    shrinkVertically(direction: VerticalDirection): InnerSelection;
    forEachSelectedLevel<T>(handler: (level: VisualLevel, rowIndex: number, columnIndex: number) => T): void;
    accept<T>(visitor: SelectionVisitor<T>): T;
    serialize(terminalSerializer: TerminalSerializer): SerializedSpaceSelection;
    static deserialize(selectionHistoryManager: SelectionHistory, visualGraph: VisualGraph, terminalSerializer: TerminalSerializer, serialized: SerializedSpaceSelection): SpaceSelection;
}
