/**
 * @hidden
 * @packageDocumentation
 */
import { KatexTree } from "./tree/AST";
import { KatexNodeVisitor } from "./tree/visitors";
import { Operation } from "./tree/op";
import { Text } from "./tree/text";
import { AbstractSymbol } from "./tree/symbols";
import { ArrayEnvironment, CasesEnvironment, MatrixEnvironment } from "./tree/environment";
import { Fraction } from "./tree/genfrac";
import { Placeholder } from "./tree/placeholder";
import { Phantom } from "./tree/phantom";
import { Accent } from "./tree/accent";
import { AccentUnder } from "./tree/accentunder";
import { ExtensibleArrow } from "./tree/arrow";
import { Color } from "./tree/color";
import { Delimsizing, LeftRight, Middle } from "./tree/delimsizing";
import { Box } from "./tree/enclose";
import { Font } from "./tree/font";
import { MathClass } from "./tree/mclass";
import { Ordgroup } from "./tree/ordgroup";
import { HorizontalBrace } from "./tree/horizBrace";
import { Lap } from "./tree/lap";
import { Kern } from "./tree/kern";
import { Overline } from "./tree/overline";
import { Supsub } from "./tree/supsub";
import { Underline } from "./tree/underline";
import { OperatorName } from "./tree/operatorname";
import { RaiseBox } from "./tree/raisebox";
import { Rule } from "./tree/rule";
import { Sizing } from "./tree/sizing";
import { Smash } from "./tree/smash";
import { Sqrt } from "./tree/sqrt";
import { Styling } from "./tree/styling";
import { Href } from "./tree/href";
import { VisualSymbol } from "../../structure/visual-levels";
import { KatexNodeRect } from "./types";
export declare class MetricsVisitor implements KatexNodeVisitor<KatexNodeRect> {
    private readonly rootElement;
    private readonly katexNodeElementCache;
    constructor(element: Element, katexNodeElementCache: Map<string, Element>);
    private rect;
    private childRect;
    private enclosingWithChildRect;
    visitRoot(tree: KatexTree): KatexNodeRect;
    visitOperation(node: Operation): KatexNodeRect;
    visitText(node: Text): KatexNodeRect;
    visitColor(node: Color): KatexNodeRect;
    visitRule(node: Rule): KatexNodeRect;
    visitMathClass(node: MathClass): KatexNodeRect;
    visitLap(node: Lap): KatexNodeRect;
    visitSmash(node: Smash): KatexNodeRect;
    visitFont(node: Font): KatexNodeRect;
    visitEnclose(node: Box): KatexNodeRect;
    visitRaiseBox(node: RaiseBox): KatexNodeRect;
    visitStyling(node: Styling): KatexNodeRect;
    visitSizing(node: Sizing): KatexNodeRect;
    visitKern(node: Kern): KatexNodeRect;
    visitSqrt(node: Sqrt): KatexNodeRect;
    visitAccent(node: Accent): KatexNodeRect;
    visitHorizontalBrace(node: HorizontalBrace): KatexNodeRect;
    visitAccentUnder(node: AccentUnder): KatexNodeRect;
    visitExtensibleArrow(node: ExtensibleArrow): KatexNodeRect;
    visitSupsub(node: Supsub): KatexNodeRect;
    visitLeftRight(node: LeftRight): KatexNodeRect;
    visitOrdgroup(node: Ordgroup): KatexNodeRect;
    visitOverline(node: Overline): KatexNodeRect;
    visitUnderline(node: Underline): KatexNodeRect;
    visitAbstractSymbol(node: AbstractSymbol): KatexNodeRect;
    visitArrayEnvironment(node: ArrayEnvironment): KatexNodeRect;
    visitMatrixEnvironment(node: MatrixEnvironment): KatexNodeRect;
    visitCasesEnvironment(node: CasesEnvironment): KatexNodeRect;
    visitFraction(node: Fraction): KatexNodeRect;
    visitPlaceholder(node: Placeholder): KatexNodeRect;
    visitPhantom(node: Phantom): KatexNodeRect;
    visitDelimsizing(node: Delimsizing): KatexNodeRect;
    visitOperatorName(node: OperatorName): KatexNodeRect;
    visitHref(node: Href): KatexNodeRect;
    /**
     *  Так как на элементе соответствующему Middle нету отличительных аттрибутов, мы ищем его в родителе между
     *  курсорами оборачивающими его
     */
    visitMiddle(node: Middle): KatexNodeRect;
    private getOpenRect;
    private getCloseRect;
    private selectNodeElement;
}
/**
 * Return ClientReact that includes all the given KatexNodeRects.
 * @param rects
 * @category API
 */
export declare function enclosingRect(...rects: KatexNodeRect[]): KatexNodeRect;
export declare class MetricsRows {
    rows: MetricsRow[];
    constructor(visibleBaseLevelSymbols: {
        symbol: VisualSymbol;
        metric: KatexNodeRect;
    }[]);
    addMetrics(metrics: KatexNodeRect[], baseLevelId: number, id: number): void;
    getRowNumberByBaseLevelSymbolId(id: number): number;
    get nonEmptyRows(): MetricsRow[];
}
export declare class MetricsRow {
    ids: number[];
    rects: KatexNodeRect[];
    baseLevelIds: number[];
    right: number;
    bottom: number;
    push(rects: KatexNodeRect[], id: number): void;
    get isEmpty(): boolean;
}
