/**
 * @hidden
 * @packageDocumentation
 */
import { Editor, NavDirection, Stateful, HorizontalNavDirection } from "../editor/editor";
import { InsertOperation } from "../model/insert-operation";
import { ConfirmRequiredOperation } from "../engine/internal-engine";
import { AnyNode, RootNode, Terminal, TerminalPointer } from "../model/model-base";
import { LevelLocation, VisualGraph } from "../structure/visual-levels";
import { SelectionEditor } from "../editor/selection-editor";
import { EditableGroupRoot, MultiCellEditor } from "../editor/multcell-editor";
import { SemanticContext } from "../engine/semantic-context";
import { Selection } from "../engine/selection/selection";
import { HorizontalDirection, VerticalDirection } from "../engine/utils";
import { UndoRedoEditor, UndoRedoEditorState } from "../editor/undo-redo-editor";
import { CursorPosition } from "../model/cursor-position";
export declare class BasicTyper implements Editor {
    private readonly editor;
    constructor(editor: Editor);
    setRoot(root: RootNode): void;
    handleInsertOperation(insertOperation: InsertOperation, log?: boolean, beforeHintPointerAcceptor?: (pointer: TerminalPointer) => void): boolean;
    handleDeleteOperation(direction: HorizontalDirection, askToForce: boolean, log?: boolean, beforeHintPointerAcceptor?: (pointer: TerminalPointer) => void, stateCallback?: (success: boolean) => void): ConfirmRequiredOperation;
    backToVisualParent(placeCursorAtLeft?: boolean): boolean;
    moveToVisualChild(levelLocation: LevelLocation, preferRight?: boolean): boolean;
    setToBaseVisualLevel(): void;
    skipSymbol(skipBackToParent: boolean): boolean;
    placeCursorAtPointer(pointer: TerminalPointer, log?: boolean): void;
    navigate(where: HorizontalNavDirection, withBackToParent?: boolean): boolean;
    moveToLevelEdge(direction: HorizontalDirection, skipBackToParent?: boolean): boolean;
    moveRight(): boolean;
    moveLeft(): boolean;
    moveHome(): boolean;
    set onUpdate(value: () => void);
    moveEnd(): boolean;
    clone(): Editor;
    get cursorPosition(): CursorPosition;
    get cursorAtBaseLevel(): boolean;
    setCursorPosition(cursorPosition: CursorPosition): void;
    get visualGraph(): VisualGraph;
    getRoot(): RootNode;
    get semanticContext(): SemanticContext;
    set semanticContext(val: SemanticContext);
    handleTyping(str: string, log?: boolean): TerminalPointer;
    handleTypingKey(charCode: number, log?: boolean, beforeHintPointerAcceptor?: (pointer: TerminalPointer) => void): TerminalPointer;
    getAnyPointer(): TerminalPointer;
    moveRightN(n: number): number;
    moveLeftN(n: number): number;
    fireHints(): void;
    rebuildVisualGraph(): void;
    replaceChild(existingChild: AnyNode, newChild: AnyNode): boolean;
    getBoundaryTerminal(left: boolean, onlyVisible?: boolean): Terminal;
}
export declare class SelTyper extends BasicTyper implements SelectionEditor {
    readonly selEditor: SelectionEditor;
    constructor(editor: SelectionEditor);
    clone(): SelectionEditor;
    setSelection(sel: Terminal[], leftToRight?: boolean): void;
    dropSelection(putCursorAtSelectionEnd: boolean): boolean;
    selectionStep(nav: NavDirection): boolean;
    createSelection(startPointer: TerminalPointer, stop: Terminal, horizontalDirection: HorizontalDirection, verticalDirection: VerticalDirection): boolean;
    moveSelectionHorizontalBoundary(leftBoundary: boolean, direction: HorizontalDirection): boolean;
    moveSelectionVerticalBoundary(topBoundary: boolean, direction: VerticalDirection): boolean;
    get selection(): Selection;
    copyTree(): AnyNode;
    copy(): string;
    cut(): string;
    paste(s: string): void;
    pasteInsertOperation(insertOperation: InsertOperation): void;
    replaceChild(existingChild: AnyNode, newChild: AnyNode): boolean;
}
export declare class MultiCellTyper extends SelTyper implements MultiCellEditor {
    private readonly multiCellEditor;
    constructor(editor: MultiCellEditor);
    clone(): MultiCellEditor;
    makeEditable(node: AnyNode, borderVisible: boolean, avoidParenthesesWrap: boolean, skipFireHints: boolean): void;
    setMathExpression(exp: string): void;
    getEditableGroupRoots(): EditableGroupRoot[];
}
export declare class UndoRedoTyper extends MultiCellTyper implements UndoRedoEditor, Stateful<UndoRedoEditorState> {
    private readonly undoRedoEditor;
    constructor(editor: UndoRedoEditor & Stateful<UndoRedoEditorState>);
    undo(): boolean;
    redo(): boolean;
    saveCurrentState(): void;
    restoreState(state: UndoRedoEditorState): void;
    saveState(): UndoRedoEditorState;
    clone(): UndoRedoEditor;
}
